# relax-py

A Python web development framework for `htmx` and `tailwindcss`, with hot module replacement, URL locators, dependency injection, supported by static typing, built on top of [Starlette](https://www.starlette.io/).

Documentation at [https://crpier.github.io/relax-py/](https://crpier.github.io/relax-py/)
